==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/UpdateBaiduChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UpdateBaiduChannelRequest(
    applicationId: __string,
    baiduChannelRequest: zio.aws.pinpoint.model.BaiduChannelRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest = {
    import UpdateBaiduChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .baiduChannelRequest(baiduChannelRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.UpdateBaiduChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.UpdateBaiduChannelRequest.wrap(buildAwsValue())
}
object UpdateBaiduChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.UpdateBaiduChannelRequest =
      zio.aws.pinpoint.model.UpdateBaiduChannelRequest(
        applicationId,
        baiduChannelRequest.asEditable
      )
    def applicationId: __string
    def baiduChannelRequest: zio.aws.pinpoint.model.BaiduChannelRequest.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getBaiduChannelRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.BaiduChannelRequest.ReadOnly
    ] = ZIO.succeed(baiduChannelRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
  ) extends zio.aws.pinpoint.model.UpdateBaiduChannelRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val baiduChannelRequest
        : zio.aws.pinpoint.model.BaiduChannelRequest.ReadOnly =
      zio.aws.pinpoint.model.BaiduChannelRequest
        .wrap(impl.baiduChannelRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
  ): zio.aws.pinpoint.model.UpdateBaiduChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/UpdateBaiduChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UpdateBaiduChannelRequest(
    applicationId: __string,
    baiduChannelRequest: zio.aws.pinpoint.model.BaiduChannelRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest = {
    import UpdateBaiduChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .baiduChannelRequest(baiduChannelRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.UpdateBaiduChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.UpdateBaiduChannelRequest.wrap(buildAwsValue())
}
object UpdateBaiduChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.UpdateBaiduChannelRequest =
      zio.aws.pinpoint.model.UpdateBaiduChannelRequest(
        applicationId,
        baiduChannelRequest.asEditable
      )
    def applicationId: __string
    def baiduChannelRequest: zio.aws.pinpoint.model.BaiduChannelRequest.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getBaiduChannelRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.BaiduChannelRequest.ReadOnly
    ] = ZIO.succeed(baiduChannelRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
  ) extends zio.aws.pinpoint.model.UpdateBaiduChannelRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val baiduChannelRequest
        : zio.aws.pinpoint.model.BaiduChannelRequest.ReadOnly =
      zio.aws.pinpoint.model.BaiduChannelRequest
        .wrap(impl.baiduChannelRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateBaiduChannelRequest
  ): zio.aws.pinpoint.model.UpdateBaiduChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}
